
(function()
{
	var $=this.Zepto;
	
	var cfg=
	{
		calendarContainer:null,
		goPrevMonthCallback:null,
		goCurrMonthCallback:null,
		goNextMonthCallback:null,
		afterDayClickHandle:null
	};
	
	var cache=
	{
		currentYear:null,
		currentMonth:null,
		currentDay:null,
		currentMonthDayNums:null
	};
	
	var template='<div id="calendar-main">\
					<div class="calendar-title">\
					    <a class="calendar-prev-month" href="javascript:"><</a>\
						    <a class="calendar-select-year"></a>\
						    <a class="calendar-select-month"></a>\
						    <a class="calendar-curr-month" href="javascript:">今天</a>\
					    <a class="calendar-next-month"  href="javascript:">></a>\
					</div>\
					<div class="calendar-context">\
						<div class="calendar-week">\
							<h3> 一 </h3>\
							<h3> 二 </h3>\
							<h3> 三 </h3>\
							<h3> 四 </h3>\
							<h3> 五 </h3>\
							<h3> 六 </h3>\
							<h3> 日 </h3>\
						</div>\
						<div class="calendar-day">\
						</div>\
					</div>\
				</div>';
	
	var isLeapYear=function(dateVal) 
	{
		return (0 == dateVal % 4 && (dateVal % 100 != 0 || dateVal % 400 == 0));
	};
	
	var getDayOfWeek=function(y, m, d) 
	{
		var theDate = new Date(y,m-1,d);
		
	    var weekday = [7,1,2,3,4,5,6];
	    
	    var dayOfWeek = weekday[theDate.getDay()];
	    
	    return dayOfWeek;
	};
	
	var getMonthDayCount=function(year,month) 
	{
		var dayCount = 30;
		month=parseInt(month);
		
		if (month === 2) 
		{
			dayCount = isLeapYear(year) ? 29 : 28;
		}
		else if ([0 , 1 , 3 , 5 , 7 , 8 , 10 , 12].indexOf(month) > -1) 
		{
			dayCount = 31;
		}
		
		return dayCount;
	};
	
	var formatDay=function(year,month,day)
	{
		var str='';
		
		str += year+'-';
		
		if(month<10)
		{
			str += '0' + month + '-';
		}
		else
		{
			str += month + '-';
		}
		
		if(day<10)
		{
			str += '0' + day;
		}
		else
		{
			str += day;
		}
		
		return str;
	};
	
	
	var createDayItem = function(y, m, d) 
	{
		var items = [];

		var nowDate = new Date();
		if(y==nowDate.getFullYear() && m==nowDate.getMonth()+1 || (y==0&&m==0) )
		{
			$('.calendar-curr-month')[0].style.visibility='hidden';
		}
		
		var year = cache.currentYear = (y == 0) ? nowDate.getFullYear() : y;
		var month = cache.currentMonth = (m == 0) ? nowDate.getMonth() + 1 : m;
		var day = cache.currentDay = (d == 0) ? nowDate.getDate() : d;
		
		$(".calendar-select-year").html(year + "年");
		$(".calendar-select-month").html(month + "月");
		
		var thisMonthDayCount = cache.currentMonthDayNums = getMonthDayCount(year,month);
		var nowWeek = getDayOfWeek(year, month, 1);
		var lastMonthDayCount = getMonthDayCount(year,(month - 1));
		
		for (var i = (lastMonthDayCount - (nowWeek - 1)); i < lastMonthDayCount; i++) 
		{
			items.push('<div class=\"day-item day-item-unable\" data-date=\"'+formatDay(year,(month-1),(i + 1))+'\" ><a>' + (i + 1) + '</a></div>');
		}
		
		for (var i = 0; i < thisMonthDayCount; i++) 
		{
			if (i == (day - 1))
			{
				items.push('<div class=\"day-item day-item-current\" data-date=\"'+formatDay(year,month,(i + 1))+'\"><a>' + (i + 1) + '</a></div>');
			}
			else
			{
				items.push('<div class=\"day-item\" data-date=\"'+formatDay(year,month,(i + 1))+'\"><a>' + (i + 1) + '</a></div>');
			}
		}

		var hasCreateDaysNum = nowWeek + thisMonthDayCount;
		if (hasCreateDaysNum < 42) 
		{
			for (var i = 0; i <= (42 - hasCreateDaysNum); i++) 
			{
				items.push('<div class=\"day-item day-item-unable\" data-date=\"'+formatDay(year,(month+1),(i + 1))+'\"><a>' + (i + 1) + '</a></div>');
			}
		}

		var $dayItem =$(items.join(''));
		$dayItem.not('.day-item-unable').on('click',function(e)
		{
			$('.day-item').removeClass('day-item-current');
			$(this).addClass('day-item-current');
			
			var dateVal=e.currentTarget.getAttribute('data-date');
			
			(typeof cfg.afterDayClickHandle === 'function') && cfg.afterDayClickHandle(dateVal);
		});

		return $dayItem;
	};

	var goPrevMonth=function()
	{
		$('.calendar-curr-month')[0].style.visibility='visible';
				
		var y = (cache.currentMonth == 1) ? (cache.currentYear - 1) : cache.currentYear;
		var m = (cache.currentMonth == 1) ? 12 : (cache.currentMonth - 1);
		var d = 0;
		
		var nowDate = new Date();
		if (y == nowDate.getFullYear() && m == nowDate.getMonth() + 1)
		{
			d = nowDate.getDate();
		}
		else
		{
			d = 1;
		}
		
		var calendar = createDayItem(y, m, d);
		$('.calendar-day').empty().append(calendar);
		
		(typeof cfg.goPrevMonthCallback === 'function') && setTimeout(cfg.goPrevMonthCallback,100);
	};

	var goCurrMonth=function()
	{
		$('.calendar-curr-month')[0].style.visibility='hidden';
		var calendar = createDayItem(0, 0, 0);
		$('.calendar-day').empty().append(calendar);
		(typeof cfg.goCurrMonthCallback === 'function') && setTimeout(cfg.goCurrMonthCallback,100);
	};
	
	var goNextMonth=function()
	{
		$('.calendar-curr-month')[0].style.visibility='visible';
		
		var y = (cache.currentMonth == 12) ? (cache.currentYear + 1) : cache.currentYear;
		var m= (cache.currentMonth == 12) ? 1 : (cache.currentMonth + 1);
		var d = 0;
		
		var nowDate = new Date();
		if (y == nowDate.getFullYear() && m == nowDate.getMonth() + 1)
		{
			d = nowDate.getDate();
		}
		else
		{
			d = 1;
		}
		
		var calendar = createDayItem(y, m, d);
		$('.calendar-day').empty().append(calendar);
		
		(typeof cfg.goNextMonthCallback === 'function') && setTimeout(cfg.goNextMonthCallback,100);
	};

	var init=function(options)
	{
		cfg=$.extend(cfg, options);
		
		cfg.calendarContainer.empty().append(template);
		
		cfg.calendarContainer.find('.calendar-prev-month').on('click',goPrevMonth);
		cfg.calendarContainer.find('.calendar-curr-month').on('click',goCurrMonth);
		cfg.calendarContainer.find('.calendar-next-month').on('click',goNextMonth);
		
		goCurrMonth();
	};
	
	this.calendar=
	{
		init:init,
		getCalendarInfo:function(){return cache;},
		
		version:'0.0.1',
		date:'2015.10.27',
		author:'liu_ning@sina.cn'
	};
	
}).call(this);